<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AppMgmtDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1303"/>
        <source>Manage External Applications</source>
        <translation>Externe Anwendungen verwalten</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1315"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1317"/>
        <source>Application path and arguments</source>
        <translation>Programmpfad und -argumente</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1323"/>
        <source>Choose</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1327"/>
        <source>Add manually</source>
        <translation>Manuell hinzufügen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1331"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1338"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1378"/>
        <source>Choose Application</source>
        <translation>Anwendung auswählen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1390"/>
        <source>New Application</source>
        <translation>Neue Applikation</translation>
    </message>
</context>
<context>
    <name>ColorsDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1008"/>
        <source>Colors</source>
        <translation>Farben</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1014"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1019"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1027"/>
        <source>Hue</source>
        <translation>Farbton</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1028"/>
        <source>Saturation</source>
        <translation>Sättigung</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1029"/>
        <source>Lightness</source>
        <translation>Helligkeit</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="vanished">Kanäle</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="vanished">Aktivieren</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1038"/>
        <source>Colorize</source>
        <translation>Einfärben</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1042"/>
        <location filename="../dialogs.cpp" line="1046"/>
        <location filename="../dialogs.cpp" line="1050"/>
        <source>Negative</source>
        <translation>Negativ</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1069"/>
        <location filename="../dialogs.cpp" line="1135"/>
        <source>Red</source>
        <translation>Rot</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1074"/>
        <location filename="../dialogs.cpp" line="1143"/>
        <source>Green</source>
        <translation>Grün</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1079"/>
        <location filename="../dialogs.cpp" line="1151"/>
        <source>Blue</source>
        <translation>Blau</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1096"/>
        <source>Hue and Saturation</source>
        <translation>Farbton und Sättigung</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1102"/>
        <source>Affected Channels</source>
        <translation>Betroffene Kanäle</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1106"/>
        <source>Brightness</source>
        <translation>Helligkeit</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1107"/>
        <source>Contrast</source>
        <translation>Kontrast</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1131"/>
        <source>Brightness and Contrast</source>
        <translation>Helligkeit und Kontrast</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1171"/>
        <source>Color Balance</source>
        <translation>Farbabstimmung</translation>
    </message>
</context>
<context>
    <name>CopyMoveToDialog</name>
    <message>
        <source>Copy or Move Images to...</source>
        <translation type="vanished">Bilder kopieren oder verschieben nach...</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="vanished">Hinzufügen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1407"/>
        <source>Move to...</source>
        <translation>Verschieben nach...</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1410"/>
        <source>Copy to...</source>
        <translation>Kopieren nach...</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1438"/>
        <source>Browse...</source>
        <translation>Durchsuchen...</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1440"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1447"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1452"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1463"/>
        <location filename="../dialogs.cpp" line="1489"/>
        <source>Destination:</source>
        <translation>Ziel:</translation>
    </message>
    <message>
        <source>Destination: </source>
        <translation type="vanished">Ziel: </translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Schließen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Kopieren</translation>
    </message>
    <message>
        <source>Move</source>
        <translation type="vanished">Verschieben</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1529"/>
        <source>Choose Folder</source>
        <translation>Verzeichnis wählen</translation>
    </message>
</context>
<context>
    <name>CpMvDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="28"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="113"/>
        <location filename="../dialogs.cpp" line="141"/>
        <source>Copying &quot;%1&quot; to &quot;%2&quot;.</source>
        <translation>Kopiere &quot;%1&quot; nach &quot;%2&quot;.</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="113"/>
        <location filename="../dialogs.cpp" line="142"/>
        <source>Moving &quot;%1&quot; to &quot;%2&quot;.</source>
        <translation>Verschiebe &quot;%1&quot; nach &quot;%2&quot;.</translation>
    </message>
    <message>
        <source>Copying </source>
        <translation type="vanished">Kopiere </translation>
    </message>
    <message>
        <source>Moving </source>
        <translation type="vanished">Verschiebe </translation>
    </message>
    <message>
        <source> to </source>
        <translation type="vanished"> nach </translation>
    </message>
</context>
<context>
    <name>CropDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="688"/>
        <source>Cropping</source>
        <translation>Zuschneiden</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="696"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="699"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="737"/>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="735"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="736"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="738"/>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
</context>
<context>
    <name>ImageTags</name>
    <message>
        <location filename="../tags.cpp" line="59"/>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="63"/>
        <source>Untag</source>
        <translation type="unfinished">Untag</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="73"/>
        <source>Clear Filters</source>
        <translation>Filter zurücksetzen</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="66"/>
        <source>New Tag</source>
        <translation>Neuer Tag</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="36"/>
        <source>Image Tags</source>
        <translation type="unfinished">Image Tags</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="37"/>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="70"/>
        <source>Remove Tag</source>
        <translation>Tag entfernen</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="77"/>
        <source>Negate</source>
        <translation>Umkehren</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="179"/>
        <location filename="../tags.cpp" line="482"/>
        <location filename="../tags.cpp" line="491"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="179"/>
        <source>Failed to save tags to </source>
        <translation>Speichern des Tags fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="381"/>
        <source>Tagging </source>
        <translation type="unfinished">Tagging </translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="384"/>
        <source>Untagging </source>
        <translation type="unfinished">Untagging </translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="473"/>
        <source>Add a new tag</source>
        <translation>Neuen Tag hinzufügen</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="474"/>
        <source>Enter new tag name</source>
        <translation>Namen des Tags eingeben</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="482"/>
        <source>No name entered</source>
        <translation>Kein Name eingegeben</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="491"/>
        <source>Tag </source>
        <translation>Tag</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="491"/>
        <source> already exists</source>
        <translation> existiert bereits</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="508"/>
        <source>Remove selected tags(s)?</source>
        <translation>Ausgewählte(n) Tag(s) entfernen?</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="509"/>
        <source>Remove tag</source>
        <translation>Tag entfernen</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="514"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="515"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <location filename="../imageview.cpp" line="626"/>
        <source>Clipboard</source>
        <translation>Zwischenablage</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="780"/>
        <source>Selection size: </source>
        <translation>Größe auswählen:</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="828"/>
        <source>No selection</source>
        <translation>Keine Auswahl</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="828"/>
        <source>Hold down the Ctrl key and select a region using the mouse.</source>
        <translation>Halten Sie die STRG-Taste gedrückt und markieren einen Bereich mit der Maus.</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="975"/>
        <location filename="../imageview.cpp" line="1021"/>
        <source>Failed to save image.</source>
        <translation>Fehler beim Speichern.</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="988"/>
        <source>Failed to save Exif metadata.</source>
        <translation>Fehler beim Speichern der EXIF-Metadaten.</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="993"/>
        <location filename="../imageview.cpp" line="1034"/>
        <source>Image saved.</source>
        <translation>Bild gespeichert.</translation>
    </message>
    <message>
        <source>Hold down the Ctrl key and select a region using the mouse</source>
        <translation type="vanished">Halten Sie die STRG-Taste gedrückt und markieren einen Bereich mit der Maus</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="958"/>
        <source>Saving...</source>
        <translation>Speichere...</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="975"/>
        <location filename="../imageview.cpp" line="988"/>
        <location filename="../imageview.cpp" line="1021"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Failed to save image</source>
        <translation type="vanished">Fehler beim Speichern</translation>
    </message>
    <message>
        <source>Failed to save Exif metadata</source>
        <translation type="vanished">Fehler beim Speichern der EXIF-Metadaten</translation>
    </message>
    <message>
        <source>Image saved</source>
        <translation type="vanished">Bild gespeichert</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="1005"/>
        <source>Save image as</source>
        <translation>Bild speichern als</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="1007"/>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="vanished">Bild-Dateien</translation>
    </message>
</context>
<context>
    <name>InfoView</name>
    <message>
        <location filename="../infoview.cpp" line="40"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
</context>
<context>
    <name>KeyGrabLineEdit</name>
    <message>
        <source>Set shortcut</source>
        <translation type="vanished">Verknüpfung setzen</translation>
    </message>
    <message>
        <source> is reserved for shortcuts to external applications</source>
        <translation type="vanished"> ist für Zugriff auf externe Programme reserviert</translation>
    </message>
    <message>
        <source> is already assigned to &quot;</source>
        <translation type="vanished"> ist bereits &quot;</translation>
    </message>
    <message>
        <source>&quot; action</source>
        <translation type="vanished">&quot; zugewiesen</translation>
    </message>
</context>
<context>
    <name>Phototonic</name>
    <message>
        <location filename="../mainwindow.cpp" line="117"/>
        <source>Image Info</source>
        <translation>Bildinformationen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <location filename="../mainwindow.cpp" line="201"/>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="223"/>
        <location filename="../mainwindow.cpp" line="224"/>
        <source>Transform</source>
        <translation>Transformieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Close Image</source>
        <translation>Bild schließen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Full Screen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>Preferences</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Enlarge Thumbnails</source>
        <translation>Miniaturansichten vergrößern</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Shrink Thumbnails</source>
        <translation>Miniaturansichten verkleinern</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="324"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Copy to...</source>
        <translation>Kopieren nach...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>Move to...</source>
        <translation>Verschieben nach...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>Copy Image Data</source>
        <translation>Bild-Daten kopieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="353"/>
        <source>Paste Image Data</source>
        <translation>Bild-Daten einfügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>Hide Dock Title Bars</source>
        <translation>Dock-Titelleiste verbergen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="426"/>
        <source>Show Toolbar</source>
        <translation>Werkzeugleiste anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="482"/>
        <source>Go Up</source>
        <translation>Nach oben</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Load Clipboard</source>
        <translation>Zwischenablage laden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="531"/>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>Open With...</source>
        <translation>Öffnen mit...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>Crop to Selection</source>
        <translation>Auswahl zum Zuschneiden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="649"/>
        <source>Lock Transformations</source>
        <translation>Transformationen beibehalten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="671"/>
        <source>Filter by Name</source>
        <translation>Nach Namen filtern</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>Set Path</source>
        <translation>Pfad setzen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>&amp;Tools</source>
        <translation>&amp;Werkzeuge</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="825"/>
        <source>Image</source>
        <translation>Bild</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="922"/>
        <source>Bookmarks</source>
        <translation>Lesezeichen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>Tags</source>
        <translation>Tags</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1384"/>
        <source>Minimum zoom</source>
        <translation>Kleinster Zoom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1402"/>
        <source>Maximum zoom</source>
        <translation>Größter Zoom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1459"/>
        <location filename="../mainwindow.cpp" line="1468"/>
        <location filename="../mainwindow.cpp" line="1525"/>
        <location filename="../mainwindow.cpp" line="1534"/>
        <source>Rotation %1°</source>
        <translation>Drehung %1°</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2703"/>
        <source>Failed to open file &quot;%1&quot;, file not found.</source>
        <translation>Öffnen der Datei fehlgeschlagen &quot;%1&quot;: Datei wurde nicht gefunden.</translation>
    </message>
    <message>
        <source>Failed to open file &quot;%1&quot;: file not found.</source>
        <translation type="vanished">Öffnen der Datei fehlgeschlagen &quot;%1&quot;: Datei wurde nicht gefunden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2983"/>
        <source>Can not move or copy images to this folder.</source>
        <translation>Verschieben oder Kopieren von Bildern in dieses Verzeichnis nicht möglich.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2989"/>
        <source>Destination folder is same as source.</source>
        <translation>Ziel- und Quellverzeichnis sind identisch.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2997"/>
        <source>Move &quot;%1&quot; to &quot;%2&quot;?</source>
        <translation>Verschiebe &quot;%1&quot; nach &quot;%2&quot;?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3006"/>
        <source>Failed to move folder.</source>
        <translation>Verschieben des Verzeichnisses fehlgeschlagen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3108"/>
        <source>Failed to open folder:</source>
        <translation>Öffnen des Verzeichnisses fehlgeschlagen:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3140"/>
        <source>Duplicate images in %1</source>
        <translation>Duplikate in %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3164"/>
        <location filename="../mainwindow.cpp" line="3338"/>
        <source>Invalid name entered.</source>
        <translation>Name ungültig.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3175"/>
        <source>Failed to rename folder.</source>
        <translation>Umbenennen des Verzeichnisses fehlgeschlagen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3222"/>
        <source>Enter a new name for &quot;%1&quot;:</source>
        <translation>Neuen Namen eingeben &quot;%1&quot;:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3235"/>
        <source>No name entered.</source>
        <translation>Kein Name eingegeben.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3265"/>
        <source>Failed to rename image.</source>
        <translation>Umbenennen des Bildes fehlgeschlagen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3281"/>
        <source>Permanently delete &quot;%1&quot; and all of its contents?</source>
        <translation>Endgültig löschen &quot;%1&quot; und der gesamte Inhalt?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3304"/>
        <source>Failed to delete folder.</source>
        <translation>Löschen des Verzeichnisses fehlgeschlagen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3308"/>
        <source>Removed &quot;%1&quot;</source>
        <translation>Entfernt &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3349"/>
        <source>Failed to create new folder.</source>
        <translation>Erstellen des neuen Verzeichnisses fehlgeschlagen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3354"/>
        <source>Created &quot;%1&quot;</source>
        <translation>Erstellt &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3395"/>
        <source>Cannot perform action with temporary image.</source>
        <translation>Aktion kann mit temporärem Bild nicht ausgeführt werden.</translation>
    </message>
    <message>
        <source>Failed to start external application</source>
        <translation type="vanished">Externe Anwendung konnte nicht gestartet werden</translation>
    </message>
    <message>
        <source>Zoom </source>
        <translation type="vanished">Zoom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1416"/>
        <source>Zoom Reset</source>
        <translation>Zoom zurücksetzen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1431"/>
        <source>Zoom Locked</source>
        <translation>Zoom beibehalten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1433"/>
        <source>Zoom Unlocked</source>
        <translation>Zoom entsperren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1442"/>
        <source>Transformations Locked</source>
        <translation>Transformationen beibehalten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1447"/>
        <source>Transformations Unlocked</source>
        <translation>Transformationen entsperren</translation>
    </message>
    <message>
        <source>Rotation </source>
        <translation type="vanished">Drehung </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1475"/>
        <source>Flipped Vertically</source>
        <translation>Vertikal gespiegelt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1475"/>
        <source>Unflipped Vertically</source>
        <translation>Vertikal spiegeln rückgängig</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1482"/>
        <source>Flipped Horizontally</source>
        <translation>Horizontal gespiegelt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1482"/>
        <source>Unflipped Horizontally</source>
        <translation>Horizontal spiegeln rückgängig</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1578"/>
        <source>Mirroring Disabled</source>
        <translation>Spiegeln deaktiviert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1585"/>
        <source>Mirroring: Dual</source>
        <translation>Spiegeln: Zweifach</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1592"/>
        <source>Mirroring: Triple</source>
        <translation>Spiegeln: Dreifach</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1599"/>
        <source>Mirroring: Dual Vertical</source>
        <translation>Spiegeln: Zweifach vertikal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1606"/>
        <source>Mirroring: Quad</source>
        <translation>Spiegeln: Vierfach</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1651"/>
        <source>Can not copy or move to the same folder</source>
        <translation>Kopieren oder Verschieben in den selben Ordner nicht möglich</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1675"/>
        <location filename="../mainwindow.cpp" line="3027"/>
        <source>Copied</source>
        <translation>Kopiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1675"/>
        <location filename="../mainwindow.cpp" line="3027"/>
        <source>Moved</source>
        <translation>Verschieben</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1739"/>
        <source>Permanently delete</source>
        <translation>Endgültig löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1842"/>
        <source>Failed to delete image.</source>
        <translation>Löschen des Bildes fehlgeschlagen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1870"/>
        <source>Deleted</source>
        <translation>Gelöscht</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1902"/>
        <source>Invalid Path:</source>
        <translation>Ungültiger Pfad:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2216"/>
        <source>Viewer</source>
        <translation>Betrachter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2232"/>
        <source>Docks and Toolbars</source>
        <translation>Dock und Werkzeugleiste</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <location filename="../mainwindow.cpp" line="213"/>
        <source>Mirroring</source>
        <translation>Spiegeln</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>Save As</source>
        <translation>Speichern unter</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation type="vanished">Bild kopieren</translation>
    </message>
    <message>
        <source>Paste Image</source>
        <translation type="vanished">Bild einfügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <location filename="../mainwindow.cpp" line="3151"/>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>Select All</source>
        <translation>Alle auswählen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <location filename="../mainwindow.cpp" line="1069"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="370"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Time</source>
        <translation>Zeit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>Reverse</source>
        <translation>Umgekehrt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Show Hidden Files</source>
        <translation>Versteckte Dateien anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="407"/>
        <source>Show Labels</source>
        <translation>Namen anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>Small Icons</source>
        <translation>Kleine Symbole</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Classic Thumbs</source>
        <translation>Klassische Miniaturansicht</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Compact</source>
        <translation>Kompakt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Squarish</source>
        <translation>Quadratisch</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="453"/>
        <source>Include Sub-folders</source>
        <translation>Unterverzeichnisse einbeziehen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>Paste Here</source>
        <translation>Hier einfügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="465"/>
        <source>New Folder</source>
        <translation>Neues Verzeichnis</translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="vanished">Verwalten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="476"/>
        <source>Forward</source>
        <translation>Vorwärts</translation>
    </message>
    <message>
        <source>Up</source>
        <translation type="vanished">Übergeordnetes Verzeichnis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="487"/>
        <source>Home</source>
        <translation>Persönliches Verzeichnis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="492"/>
        <location filename="../mainwindow.cpp" line="2717"/>
        <source>Slide Show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>Next</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Previous</source>
        <translation>Vorheriges</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="507"/>
        <source>First</source>
        <translation>Erstes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>Last</source>
        <translation>Letztes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>Random</source>
        <translation>Zufällig</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="602"/>
        <source>Scale Image</source>
        <translation>Bild skalieren</translation>
    </message>
    <message>
        <source>&lt;u&gt;Contributors&lt;/u&gt;:&lt;br&gt;</source>
        <translation type="vanished">&lt;u&gt;Mitwirkende&lt;/u&gt;:&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;u&gt;Translators&lt;/u&gt;:&lt;br&gt;</source>
        <translation type="vanished">&lt;u&gt;Übersetzer&lt;/u&gt;:&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2745"/>
        <source>Stop Slide Show</source>
        <translation>Diashow beenden</translation>
    </message>
    <message>
        <source>New Image</source>
        <translation type="obsolete">Neues Bild</translation>
    </message>
    <message>
        <source>Open With</source>
        <translation type="vanished">Öffnen mit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="535"/>
        <source>Manage External Applications</source>
        <translation>Externe Anwendungen verwalten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Add Bookmark</source>
        <translation>Lesezeichen hinzufügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Remove Bookmark</source>
        <translation>Lesezeichen entfernen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>Zoom Out</source>
        <translation>Zoom verringern</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Zoom In</source>
        <translation>Zoom erhöhen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="558"/>
        <source>Reset Zoom</source>
        <translation>Zoom zurücksetzen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="563"/>
        <location filename="../mainwindow.cpp" line="1424"/>
        <source>Original Size</source>
        <translation>Originalgröße</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <source>Keep Zoom</source>
        <translation>Zoom beibehalten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="573"/>
        <source>Rotate 90 degree CCW</source>
        <translation>90° gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="578"/>
        <source>Rotate 90 degree CW</source>
        <translation>90° im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>Flip Horizontally</source>
        <translation>Horizontal spiegeln</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="588"/>
        <source>Flip Vertically</source>
        <translation>Vertikal spiegeln</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="593"/>
        <source>Cropping</source>
        <translation>Zuschneiden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="607"/>
        <source>Rotate 1 degree CCW</source>
        <translation>Um 1° gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="611"/>
        <source>Rotate 1 degree CW</source>
        <translation>Um 1° im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="615"/>
        <source>Colors</source>
        <translation>Farben</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="620"/>
        <source>Find Duplicate Images</source>
        <translation>Suche Duplikate</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Disable</source>
        <translation>Deaktivieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="628"/>
        <source>Dual</source>
        <translation>Zweifach</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="630"/>
        <source>Triple</source>
        <translation>Dreifach</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <source>Dual Vertical</source>
        <translation>Zweifach vertikal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <source>Quad</source>
        <translation>Vierfach</translation>
    </message>
    <message>
        <source>Keep Transformations</source>
        <translation type="vanished">Transformationen beibehalten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="654"/>
        <source>Move Left</source>
        <translation>Nach links</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="657"/>
        <source>Move Right</source>
        <translation>Nach rechts</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="660"/>
        <source>Move Up</source>
        <translation>Nach oben</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>Move Down</source>
        <translation>Nach unten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Invert Selection</source>
        <translation>Auswahl umkehren</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="obsolete">Datei</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="771"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <source>Go</source>
        <translation type="obsolete">Los</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <location filename="../mainwindow.cpp" line="253"/>
        <location filename="../mainwindow.cpp" line="801"/>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="720"/>
        <source>Sort By</source>
        <translation>Sortieren nach</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="obsolete">Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="781"/>
        <source>Navigation</source>
        <translation>Navigation</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="808"/>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="871"/>
        <source>Initializing...</source>
        <translation>Initialisiere...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="885"/>
        <source>File System</source>
        <translation>Dateisystem</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1044"/>
        <source>&lt;p&gt;Image viewer and organizer&lt;/p&gt;</source>
        <translation>&lt;p&gt;Bildbetrachter und -verwalter</translation>
    </message>
    <message>
        <source>&lt;p&gt;Built with Qt </source>
        <translation type="obsolete">&lt;p&gt;Kompiliert mit Qt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1046"/>
        <source>Home page</source>
        <translation>Homepage</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1047"/>
        <source>Bug reports</source>
        <translation>Fehlerberichte</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation type="obsolete">Kontakt</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation type="obsolete">Übersetzungen:</translation>
    </message>
    <message>
        <source>Copy or Move to...</source>
        <translation type="vanished">Kopieren oder Verschieben nach...</translation>
    </message>
    <message>
        <source>Show Lables</source>
        <translation type="obsolete">Label anzeigen</translation>
    </message>
    <message>
        <source>Compact (slower)</source>
        <translation type="obsolete">Kompakt (langsamer)</translation>
    </message>
    <message>
        <source>Show Clipboard</source>
        <translation type="vanished">Zwischenablage anzeigen</translation>
    </message>
    <message>
        <source>Resize Image</source>
        <translation type="obsolete">Bildgröße ändern</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="681"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="705"/>
        <source>&amp;Go</source>
        <translation>&amp;Los</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="714"/>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="747"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&lt;p&gt;Git release</source>
        <translation type="vanished">&lt;p&gt;Git-Version</translation>
    </message>
    <message>
        <source>Built with Qt </source>
        <translation type="vanished">&lt;p&gt;Kompiliert mit Qt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3208"/>
        <source>Invalid selection</source>
        <translation>Ungültige Auswahl</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1104"/>
        <location filename="../mainwindow.cpp" line="1330"/>
        <location filename="../mainwindow.cpp" line="1638"/>
        <location filename="../mainwindow.cpp" line="1651"/>
        <location filename="../mainwindow.cpp" line="1761"/>
        <location filename="../mainwindow.cpp" line="1842"/>
        <location filename="../mainwindow.cpp" line="1902"/>
        <location filename="../mainwindow.cpp" line="2703"/>
        <location filename="../mainwindow.cpp" line="2983"/>
        <location filename="../mainwindow.cpp" line="2989"/>
        <location filename="../mainwindow.cpp" line="3006"/>
        <location filename="../mainwindow.cpp" line="3108"/>
        <location filename="../mainwindow.cpp" line="3164"/>
        <location filename="../mainwindow.cpp" line="3175"/>
        <location filename="../mainwindow.cpp" line="3235"/>
        <location filename="../mainwindow.cpp" line="3265"/>
        <location filename="../mainwindow.cpp" line="3304"/>
        <location filename="../mainwindow.cpp" line="3338"/>
        <location filename="../mainwindow.cpp" line="3349"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Failed to copy or move image</source>
        <translation type="vanished">Kopieren oder Verschieben des Bildes fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1638"/>
        <source>Can not copy or move to </source>
        <translation>Kopieren oder Verschieben nicht möglich</translation>
    </message>
    <message>
        <source>Can not cut and paste in the same folder</source>
        <translation type="vanished">Ausschneiden und Einfügen im selben Verzeichnis nicht möglich</translation>
    </message>
    <message>
        <source>Copied </source>
        <translation type="vanished">Kopiert </translation>
    </message>
    <message>
        <source>Moved </source>
        <translation type="vanished">Verschoben </translation>
    </message>
    <message>
        <source> images</source>
        <translation type="vanished"> Bilder</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1740"/>
        <source>Delete image</source>
        <translation>Bild löschen</translation>
    </message>
    <message>
        <source>Permanently delete </source>
        <translation type="vanished">Endgültig löschen </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1761"/>
        <source>Failed to delete image</source>
        <translation>Löschen des Bildes fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1507"/>
        <location filename="../mainwindow.cpp" line="1798"/>
        <source>No selection</source>
        <translation>Keine Auswahl</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1807"/>
        <source>Delete images</source>
        <translation>Bilder löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1806"/>
        <source>Permanently delete selected images?</source>
        <translation>Möchten Sie die ausgewählten Bilder endgültig löschen?</translation>
    </message>
    <message>
        <source>Hide Docks Title Bar</source>
        <translation type="vanished">Dock-Titelleisten verbergen</translation>
    </message>
    <message>
        <source>Contributors / Code:</source>
        <translation type="vanished">Mitwirkende / Code:</translation>
    </message>
    <message>
        <source>Contributors / Translations:</source>
        <translation type="vanished">Mitwirkende / Übersetzungen:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1104"/>
        <source>Failed to start external application.</source>
        <translation>Externe Anwendung konnte nicht gestartet werden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1128"/>
        <source>Invalid selection.</source>
        <translation>Ungültige Auswahl.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1330"/>
        <source>Failed to copy or move image.</source>
        <translation>Kopieren oder Verschieben des Bildes fehlgeschlagen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1390"/>
        <location filename="../mainwindow.cpp" line="1408"/>
        <source>Zoom %1%</source>
        <translation>Zoom %1%</translation>
    </message>
    <message>
        <source>Rotation %1u00B0</source>
        <translation type="vanished">Drehung %1u00B0</translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1676"/>
        <location filename="../mainwindow.cpp" line="1870"/>
        <location filename="../mainwindow.cpp" line="3028"/>
        <source>%n image(s)</source>
        <translation>
            <numerusform>%n Bild</numerusform>
            <numerusform>%n Bilder</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1744"/>
        <location filename="../mainwindow.cpp" line="1811"/>
        <location filename="../mainwindow.cpp" line="3289"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1745"/>
        <location filename="../mainwindow.cpp" line="1812"/>
        <location filename="../mainwindow.cpp" line="3290"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1758"/>
        <source>Deleted </source>
        <translation>Gelöscht </translation>
    </message>
    <message>
        <source>Invalid Path: </source>
        <translation type="vanished">Ungültiger Pfad: </translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="vanished">Vorschau</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2554"/>
        <source>No images</source>
        <translation>Keine Bilder</translation>
    </message>
    <message>
        <source>Failed to open file </source>
        <translation type="vanished">Öffnen der Datei fehlgeschlagen </translation>
    </message>
    <message>
        <source>, file not found</source>
        <translation type="vanished">, Datei wurde nicht gefunden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2718"/>
        <source>Slide show stopped</source>
        <translation>Diashow angehalten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2746"/>
        <source>Slide show started</source>
        <translation>Diashow gestartet</translation>
    </message>
    <message>
        <source>Can not move or copy images to this folder</source>
        <translation type="vanished">Verschieben oder Kopieren von Bildern in dieses Verzeichnis nicht möglich</translation>
    </message>
    <message>
        <source>Destination folder is same as source</source>
        <translation type="vanished">Ziel- und Quellverzeichnis sind identisch</translation>
    </message>
    <message>
        <source>Move </source>
        <translation type="vanished">Verschieben</translation>
    </message>
    <message>
        <source> to </source>
        <translation type="vanished"> nach </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2998"/>
        <source>Move folder</source>
        <translation>Verzeichnis verschieben</translation>
    </message>
    <message>
        <source>Failed to move folder</source>
        <translation type="vanished">Verschieben des Verzeichnisses fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3008"/>
        <source>Folder moved</source>
        <translation>Verzeichnis verschoben</translation>
    </message>
    <message>
        <source>Failed to open folder: </source>
        <translation type="vanished">Öffnen des Verzeichnisses fehlgeschlagen:</translation>
    </message>
    <message>
        <source>Rename </source>
        <translation type="vanished">Umbenennen </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3153"/>
        <source>New name:</source>
        <translation>Neuer Name:</translation>
    </message>
    <message>
        <source>Invalid name entered</source>
        <translation type="vanished">Name ungültig</translation>
    </message>
    <message>
        <source>Failed to rename folder</source>
        <translation type="vanished">Umbenennen des Verzeichnisses fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3220"/>
        <source>Rename Image</source>
        <translation>Bild umbenennen</translation>
    </message>
    <message>
        <source>Enter a new name for </source>
        <translation type="vanished">Neuen Namen eingeben </translation>
    </message>
    <message>
        <source>No name entered</source>
        <translation type="vanished">Kein Name eingegeben</translation>
    </message>
    <message>
        <source>Failed to rename image</source>
        <translation type="vanished">Umbenennen des Bildes fehlgeschlagen</translation>
    </message>
    <message>
        <source> and all of its contents?</source>
        <translation type="vanished"> und der gesamte Inhalt?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3285"/>
        <source>Delete folder</source>
        <translation>Verzeichnis löschen</translation>
    </message>
    <message>
        <source>Failed to delete folder</source>
        <translation type="vanished">Löschen des Verzeichnisses fehlgeschlagen</translation>
    </message>
    <message>
        <source>Removed </source>
        <translation type="vanished">Entfernt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3326"/>
        <source>New Sub folder</source>
        <translation>Neues Unterverzeichnis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3327"/>
        <source>New folder name:</source>
        <translation>Neuer Verzeichnisname:</translation>
    </message>
    <message>
        <source>Failed to create new folder</source>
        <translation type="vanished">Erstellen des neuen Verzeichnisses fehlgeschlagen</translation>
    </message>
    <message>
        <source>Created </source>
        <translation type="vanished">Erstellt </translation>
    </message>
    <message>
        <source>Executing file manager...</source>
        <translation type="vanished">Datei-Manager ausführen...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3395"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <source>Cannot perform action with temporary image</source>
        <translation type="vanished">Aktion kann mit temporärem Bild nicht ausgeführt werden</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1555"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Usage: phototonic [FILE or DIRECTORY]...</source>
        <translation type="vanished">Usage: phototonic [FILE or DIRECTORY]...</translation>
    </message>
</context>
<context>
    <name>ResizeDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="813"/>
        <source>Scale Image</source>
        <translation>Bild skalieren</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="825"/>
        <source>Scale</source>
        <translation>Skalieren</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="829"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="845"/>
        <source>Original size:</source>
        <translation>Originalgröße:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="848"/>
        <source>Width:</source>
        <translation>Breite:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="849"/>
        <source>Height:</source>
        <translation>Höhe:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="850"/>
        <source>Units:</source>
        <translation>Einheit:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="852"/>
        <source>New size:</source>
        <translation>Neue Größe:</translation>
    </message>
    <message>
        <source>Original size: </source>
        <translation type="vanished">Originalgröße:</translation>
    </message>
    <message>
        <source>Width: </source>
        <translation type="vanished">Breite:</translation>
    </message>
    <message>
        <source>Height: </source>
        <translation type="vanished">Höhe:</translation>
    </message>
    <message>
        <source>Units: </source>
        <translation type="vanished">Einheit: </translation>
    </message>
    <message>
        <source>New size: </source>
        <translation type="vanished">Neue Größe: </translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="855"/>
        <source>Pixels</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="857"/>
        <source>Percent</source>
        <translation>Prozent</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="862"/>
        <source>Lock aspect ratio</source>
        <translation>Größenverhältnis beibehalten</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="270"/>
        <source>Preferences</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="277"/>
        <location filename="../dialogs.cpp" line="294"/>
        <source>By width or height</source>
        <translation>Nach Breite oder Höhe</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="331"/>
        <source>Default quality when saving images:</source>
        <translation>Standard-Bildqualität beim Speichern:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="383"/>
        <source>Label color:</source>
        <translation>Labelfarbe:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="545"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="550"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Background color: </source>
        <translation type="vanished">Hintergrundfarbe: </translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="345"/>
        <source>Rotate image according to Exif orientation</source>
        <translation>Bild gemäß EXIF-Orientierung drehen</translation>
    </message>
    <message>
        <source>	Label color: </source>
        <translation type="vanished">	Labelfarbe:</translation>
    </message>
    <message>
        <source>Background image: </source>
        <translation type="vanished">Hintergrundbild: </translation>
    </message>
    <message>
        <source>Add space between thumbnails: </source>
        <translation type="vanished">Abstand zwischen den Miniaturansichten einfügen:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="425"/>
        <source>Show original size of images smaller than the thumbnail size</source>
        <translation>Originalgröße der Bilder anzeigen, wenn sie kleiner als die Miniaturansicht ist</translation>
    </message>
    <message>
        <source>Number of thumbnail pages to read ahead: </source>
        <translation type="vanished">Anzahl der Seiten, die im Voraus eingelesen werden sollen:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="438"/>
        <source>Rotate thumbnails according to Exif orientation</source>
        <translation>Miniaturansichten gemäß EXIF-Orientierung drehen</translation>
    </message>
    <message>
        <source>Keyboard shortcuts</source>
        <translation type="vanished">Tastenkombinationen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="566"/>
        <source>Thumbnails</source>
        <translation>Miniaturansichten</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="275"/>
        <source>Fit Large Images</source>
        <translation>Große Bilder anpassen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="276"/>
        <location filename="../dialogs.cpp" line="293"/>
        <source>Disable</source>
        <translation>Deaktivieren</translation>
    </message>
    <message>
        <source>By width and height</source>
        <translation type="vanished">Nach Breite und Höhe</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="278"/>
        <location filename="../dialogs.cpp" line="295"/>
        <source>By width</source>
        <translation>Nach Breite</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="279"/>
        <location filename="../dialogs.cpp" line="296"/>
        <source>By height</source>
        <translation>Nach Höhe</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="280"/>
        <location filename="../dialogs.cpp" line="297"/>
        <source>Stretch disproportionately</source>
        <translation>Unverhältnismäßig dehnen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="292"/>
        <source>Fit Small Images</source>
        <translation>Kleine Bilder anpassen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="323"/>
        <source>Exit instead of closing, when image is loaded from command line</source>
        <translation>Beenden statt Schließen, wenn das Bild von der Kommandozeile geladen wird</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="327"/>
        <source>Wrap image list when reaching last or first image</source>
        <translation>Bilderliste umbrechen, wenn das letzte oder erste Bild erreicht wird</translation>
    </message>
    <message>
        <source>Default quality when saving images: </source>
        <translation type="vanished">Standard-Bildqualität beim Speichern:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="341"/>
        <source>Enable GIF animation</source>
        <translation>GIF-Animation aktivieren</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="681"/>
        <source>Open File</source>
        <translation>Datei öffnen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="682"/>
        <source>Images</source>
        <translation> Bilder</translation>
    </message>
    <message>
        <source>Rotate according to Exif orientation</source>
        <translation type="vanished">Gemäß EXIF-Orientierung drehen</translation>
    </message>
    <message>
        <source>Show image file name in full screen mode</source>
        <translation type="vanished">Name der Bilddatei im Vollbildmodus anzeigen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="309"/>
        <location filename="../dialogs.cpp" line="371"/>
        <source>Background color:</source>
        <translation>Hintergrundfarbe:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="349"/>
        <source>Show image file name in viewer</source>
        <translation>Dateiname im Betrachter anzeigen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="395"/>
        <source>Background image:</source>
        <translation>Hintergrundbild:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="414"/>
        <source>Add space between thumbnails:</source>
        <translation>Abstand zwischen den Miniaturansichten einfügen:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="429"/>
        <source>Number of thumbnail pages to read ahead:</source>
        <translation>Anzahl der Seiten, die im Voraus eingelesen werden sollen:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="452"/>
        <source>Delay between slides in seconds:</source>
        <translation>Verzögerung zwischen den Dias in Sekunden:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="472"/>
        <source>Startup folder</source>
        <translation>Verzeichnis bei Programmstart</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="474"/>
        <source>Default, or specified by command line argument</source>
        <translation>Standard oder mit Befehlszeilenparameter angeben</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="475"/>
        <source>Remember last</source>
        <translation>Letztes speichern</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="476"/>
        <source>Specify:</source>
        <translation>Auswählen:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="527"/>
        <source>Delete confirmation</source>
        <translation>Löschen bestätigen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="531"/>
        <source>Keyboard Shortcuts</source>
        <translation>Tastenkombinationen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="562"/>
        <source>Viewer</source>
        <translation>Betrachter</translation>
    </message>
    <message>
        <source>Delay between slides in seconds: </source>
        <translation type="vanished">Verzögerung zwischen den Dias in Sekunden:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="462"/>
        <source>Show random images</source>
        <translation>Zufällig ausgewählte Bilder anzeigen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="570"/>
        <source>Slide Show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="523"/>
        <source>Swap mouse left-click and middle-click actions</source>
        <translation>Links-Klick- und Mittel-Klick-Aktionen der Maus tauschen</translation>
    </message>
    <message>
        <source>Keyboard Shortcuts:</source>
        <translation type="vanished">Tastenkombinationen:</translation>
    </message>
    <message>
        <source>Keyboard and Mouse</source>
        <translation type="vanished">Tastatur und Maus</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="574"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="674"/>
        <source>Choose Startup Folder</source>
        <translation>Verzeichnis bei Programmstart wählen</translation>
    </message>
</context>
<context>
    <name>ShortcutsTable</name>
    <message>
        <location filename="../dialogs.cpp" line="170"/>
        <source>Action</source>
        <translation>Aktion</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="171"/>
        <source>Shortcut</source>
        <translation>Verknüpfung</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="185"/>
        <source>Delete shortcut</source>
        <translation>Verknüpfung löschen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="227"/>
        <location filename="../dialogs.cpp" line="239"/>
        <source>Set shortcut</source>
        <translation>Verknüpfung setzen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="228"/>
        <source>&quot;%1&quot; is reserved for shortcuts to external applications.</source>
        <translation>&quot;%1&quot; ist für Zugriff auf externe Programme reserviert.</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="240"/>
        <source>&quot;%1&quot; is already assigned to &quot;%2&quot; action.</source>
        <translation>&quot;%1&quot; ist bereits &quot;%2&quot; zugewiesen.</translation>
    </message>
    <message>
        <source> is reserved for shortcuts to external applications</source>
        <translation type="obsolete"> ist für Zugriff auf externe Programme reserviert</translation>
    </message>
    <message>
        <source> is already assigned to &quot;</source>
        <translation type="obsolete"> ist bereits &quot;</translation>
    </message>
    <message>
        <source>&quot; action</source>
        <translation type="obsolete">&quot; zugewiesen</translation>
    </message>
</context>
<context>
    <name>ThumbView</name>
    <message>
        <source> images</source>
        <translation type="vanished"> Bilder</translation>
    </message>
    <message>
        <source>Selected </source>
        <translation type="vanished">Ausgewählt </translation>
    </message>
    <message>
        <source> of </source>
        <translation type="vanished"> von </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="247"/>
        <source>File name</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="251"/>
        <source>Location</source>
        <translation>Speicherort</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="264"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="268"/>
        <source>Resolution</source>
        <translation>Auflösung</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="274"/>
        <source>Megapixel</source>
        <translation>Megapixel</translation>
    </message>
    <message>
        <source>Selected %1 of %2</source>
        <translation type="vanished">Ausgewählt %1 von %2</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="683"/>
        <source>Scanned %1, displaying %2 (%3 and %4)</source>
        <translation>Geprüft %1, angezeigt %2 (%3 und %4)</translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="686"/>
        <source>%n original(s)</source>
        <translation>
            <numerusform>%n Original</numerusform>
            <numerusform>%n Originale</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="687"/>
        <source>%n duplicate(s)</source>
        <translation>
            <numerusform>%n Duplikat</numerusform>
            <numerusform>%n Duplikate</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="255"/>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="245"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="259"/>
        <source>Modified</source>
        <translation>Geändert</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="282"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="463"/>
        <location filename="../thumbview.cpp" line="684"/>
        <location filename="../thumbview.cpp" line="685"/>
        <source>%n image(s)</source>
        <translation>
            <numerusform>%n Bild</numerusform>
            <numerusform>%n Bilder</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="297"/>
        <source>Selected %1 of%2</source>
        <translation>Ausgewählt %1 von%2</translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="299"/>
        <source> %n image(s)</source>
        <translation>
            <numerusform> %n Bild</numerusform>
            <numerusform> %n Bilder</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="582"/>
        <source>Searching duplicate images...</source>
        <translation>Suche Duplikate...</translation>
    </message>
    <message>
        <source>Scanned </source>
        <translation type="vanished">Geprüft </translation>
    </message>
    <message numerus="yes">
        <source>%n images, displaying </source>
        <translation type="vanished">
            <numerusform>%n Bild, angezeigt </numerusform>
            <numerusform>%n Bilder, angezeigt </numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n images (</source>
        <translation type="vanished">
            <numerusform>%n Bild (</numerusform>
            <numerusform>%n Bilder (</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n originals and </source>
        <translation type="vanished">
            <numerusform>%n Original und </numerusform>
            <numerusform>%n Originale und </numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n duplicates)</source>
        <translation type="vanished">
            <numerusform>%n Duplikat)</numerusform>
            <numerusform>%n Duplikate)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="465"/>
        <source>No images</source>
        <translation>Keine Bilder</translation>
    </message>
</context>
</TS>
